import { CSSProperties, ReactNode } from "react";
import { ColumnDescription } from "react-bootstrap-table-nextgen";
export { default as ToggleList } from "./src/column-toggle/toggle-list";
export { default as ExportCSVButton } from "./src/csv/button";
export { default as SearchBar } from "./src/search/SearchBar";
export { default as ClearSearchButton } from "./src/search/clear-button";
/**
 * declaration for table toolkit sub module
 */
export interface InjectedSearchProps {
    searchText: string;
    onSearch: (val: string) => void;
    onClear: () => void;
}
export interface SearchMatchProps<T extends object = any> {
    searchText: string;
    value: string;
    column: ColumnDescription<T>;
    row: T;
}
export interface TableSearchProps<T extends object = any> {
    searchFormatted?: boolean | undefined;
    defaultSearch?: string | undefined;
    placeholder?: string | undefined;
    onColumnMatch?: (props: SearchMatchProps<T>) => boolean;
    customMatchFunc?: ((props: SearchMatchProps<T>) => boolean) | undefined;
    afterSearch?: (newResult: T[]) => void | undefined;
    searchContext?: Function;
    searchText?: string;
}
export interface CSVProps {
    fileName?: string | undefined;
    separator?: string | undefined;
    ignoreHeader?: boolean | undefined;
    noAutoBOM?: boolean | undefined;
    /**
     * default is text/plain;charset=utf-8
     */
    blobType?: string | undefined;
    exportAll?: boolean | undefined;
    onlyExportSelection?: boolean | undefined;
    onlyExportFiltered?: boolean | undefined;
}
export interface TableToolkitProps<T extends object = any> {
    bootstrap4?: boolean | undefined;
    search?: TableSearchProps<T> | boolean | undefined;
    keyField: keyof T | string;
    data: T[];
    ref?: any;
    columns: Array<ColumnDescription<T>>;
    children: (props: ToolkitContextType) => JSX.Element;
    exportCSV?: boolean | CSVProps | undefined;
    columnToggle?: {
        [dataField: string]: boolean;
    } | boolean | undefined;
    setDependencyModules: Function;
    registerExposedAPI: Function;
}
export interface ToolkitContextType {
    searchProps: InjectedSearchProps;
    csvProps: {
        onExport: (source: any) => void;
    };
    columnToggleProps: {
        columns: ColumnDescription[];
        /**
         * array of toggled columns
         */
        toggles: boolean[];
        onColumnToggle: (dataField: string) => void;
    };
    baseProps: {
        /**
         * table key field
         */
        keyField: any;
        columns: ColumnDescription[];
        data: any[];
        bootstrap4?: boolean | undefined;
    };
}
export interface ToggleListProps {
    columns: ColumnDescription[];
    /**
     * array of toggled columns
     */
    toggles: boolean[];
    onColumnToggle: (dataField: string) => void;
    btnClassName?: string | undefined;
    className?: string | undefined;
    contextual?: string | undefined;
}
export interface ExportCSVButtonProps {
    children: ReactNode;
    onExport: () => void;
    style?: CSSProperties | undefined;
    className?: string | undefined;
}
export interface ClearSearchButtonProps {
    onClear?: (() => void) | undefined;
    className?: string | undefined;
    text?: string | undefined;
}
